@@ -9,7 +9,6 @@ from PyQtGuiLib.header import (
     QApplication,
     QWidget,
     Signal,
-    Qt,
     QFont,
     QColor,
     QPen,
@@ -17,7 +16,9 @@ from PyQtGuiLib.header import (
     QPaintEvent,
     QFontMetricsF,
     QSize,
-    QResizeEvent
+    QResizeEvent,
+    qt,
+    textSize
 )
 
 
@@ -132,15 +133,15 @@ class LoadBar(QWidget):
             painter.setFont(f)
             painter.setPen(self.text_color)
             # 文字
-            fs = QFontMetricsF(f)
-            fw = int(fs.width(self.text))
-            fh = int(fs.height())
+            fs = textSize(f,self.text)
+            fw = fs.width()
+            fh = fs.height()
             painter.drawText(self.w // 2 - fw // 2,self.h // 2 + fh // 4, self.text)
 
     def paintEvent(self, event:QPaintEvent) -> None:
         painter = QPainter()
         painter.begin(self)
-        painter.setRenderHints(painter.Antialiasing | painter.SmoothPixmapTransform | painter.TextAntialiasing)
+        painter.setRenderHints(qt.Antialiasing | qt.SmoothPixmapTransform | qt.TextAntialiasing)
 
         # 绘制进度条
         self.drawBar(painter)
