@@ -1,15 +1,12 @@
 from PyQtGuiLib.header import (
-    PYQT_VERSIONS,
-    QApplication,
     QWidget,
     QThread,
     Signal,
     QPoint,
     QPropertyAnimation,
-    QEasingCurve,
     desktopCenter,
     desktopSize,
-    Qt
+    qt
 )
 
 
@@ -45,10 +42,8 @@ class MonitoThread(QThread):
 class PullOver:
 
     # 弹力
-    if PYQT_VERSIONS == "PyQt5":
-        OutBounce = QEasingCurve.OutBounce
-    else:
-        OutBounce = None
+    OutBounce = qt.OutBounce
+
 
     def __init__(self,parent:QWidget,*args,**kwargs):
         self.parent = parent
