@@ -16,7 +16,9 @@ if PYQT_VERSIONS == "PyQt5":
         QEasingCurve,
         QByteArray,
         QSequentialAnimationGroup,
-        QParallelAnimationGroup
+        QParallelAnimationGroup,
+        QMargins,
+        QModelIndex
     )
 
 if PYQT_VERSIONS == "PyQt6":
@@ -36,6 +38,8 @@ if PYQT_VERSIONS == "PyQt6":
         QByteArray,
         QSequentialAnimationGroup,
         QParallelAnimationGroup,
+        QMargins,
+        QModelIndex
     )
 
 if PYQT_VERSIONS == "PySide2":
@@ -54,7 +58,9 @@ if PYQT_VERSIONS == "PySide2":
         QEasingCurve,
         QByteArray,
         QSequentialAnimationGroup,
-        QParallelAnimationGroup
+        QParallelAnimationGroup,
+        QMargins,
+        QModelIndex
     )
 if PYQT_VERSIONS == "PySide6":
     from PySide6.QtCore import (
@@ -72,5 +78,7 @@ if PYQT_VERSIONS == "PySide6":
         QEasingCurve,
         QByteArray,
         QSequentialAnimationGroup,
-        QParallelAnimationGroup
+        QParallelAnimationGroup,
+        QMargins,
+        QModelIndex
     )
\ No newline at end of file
