@@ -39,7 +39,17 @@ if PYQT_VERSIONS == "PyQt5":
         QStyledItemDelegate,
         QLayout,
         QLayoutItem,
-        QStyleOptionViewItem
+        QStyleOptionViewItem,
+        QTreeWidget,
+        QTreeWidgetItem,
+        QTreeWidgetItemIterator,
+        QTextBrowser,
+        QTextEdit,
+        QTabWidget,
+        QSpinBox,
+        QDoubleSpinBox,
+        QFormLayout,
+        QColorDialog
     )
 if PYQT_VERSIONS == "PyQt6":
     from PyQt6.QtWidgets import (
@@ -79,8 +89,17 @@ if PYQT_VERSIONS == "PyQt6":
         QStyledItemDelegate,
         QLayout,
         QLayoutItem,
-        QStyleOptionViewItem
-
+        QStyleOptionViewItem,
+        QTreeWidget,
+        QTreeWidgetItem,
+        QTreeWidgetItemIterator,
+        QTextBrowser,
+        QTextEdit,
+        QTabWidget,
+        QSpinBox,
+        QDoubleSpinBox,
+        QFormLayout,
+        QColorDialog
 )
 
 if PYQT_VERSIONS == "PySide2":
@@ -123,7 +142,17 @@ if PYQT_VERSIONS == "PySide2":
         QStyledItemDelegate,
         QLayout,
         QLayoutItem,
-        QStyleOptionViewItem
+        QStyleOptionViewItem,
+        QTreeWidget,
+        QTreeWidgetItem,
+        QTreeWidgetItemIterator,
+        QTextBrowser,
+        QTextEdit,
+        QTabWidget,
+        QSpinBox,
+        QDoubleSpinBox,
+        QFormLayout,
+        QColorDialog
     )
 
 if PYQT_VERSIONS == "PySide6":
@@ -164,5 +193,15 @@ if PYQT_VERSIONS == "PySide6":
         QStyledItemDelegate,
         QLayout,
         QLayoutItem,
-        QStyleOptionViewItem
+        QStyleOptionViewItem,
+        QTreeWidget,
+        QTreeWidgetItem,
+        QTreeWidgetItemIterator,
+        QTextBrowser,
+        QTextEdit,
+        QTabWidget,
+        QSpinBox,
+        QDoubleSpinBox,
+        QFormLayout,
+        QColorDialog
     )
\ No newline at end of file
