@@ -12,7 +12,6 @@ from PyQtGuiLib.header import (
     Signal,
     QColor,
     QSlider,
-    Qt
 )
 
 from PyQtGuiLib.core.progressBar import WaterBar
@@ -63,7 +62,7 @@ if __name__ == '__main__':
     win = TestPullOverWidget()
     win.show()
 
-    if PYQT_VERSIONS == "PyQt6":
+    if PYQT_VERSIONS in ["PyQt6","PySide6"]:
         sys.exit(app.exec())
     else:
-        sys.exit(app.exec_())
+        sys.exit(app.exec_())
\ No newline at end of file
